# hydroai
> This project contains all the backend logic to demonstrate the viability of machine learning methods for operational hydrologic forecasting.


## Install

`pip install hydroai`

## How to use

Checkout the following tutorials which demonstrate some initial functionality available in hydroai.

- [Processing ERA5-Land Data](https://pjbutcher.github.io/hydroai/tutorial_process_era5_land/)
- [Training a Random Forest Model on ERA5-Land Forcings](https://pjbutcher.github.io/hydroai/tutorial_simple_random_forest/)
